@@ -1,6 +1,6 @@
 """Provides public API of data validation functionality."""
 from . import casters, validators
 from .base import BaseModel, DictModel, ObjectModel, ValidationError
-from .field import cached_model_method, cast, field, json_dumps, validate
+from .field import cached_model_classmethod, cast, field, json_dumps, validate
 from .models import build, build_or_raise, set_max_cache_size
 from .type_handlers import to_dict
